Delete metadata using keys names for a TileDB array or group.
Usage
# S3 method for class 'TileDBArray'
delete_metadata(x, keys, ...)
# S3 method for class 'TileDBGroup'
delete_metadata(x, keys, ...)
# S3 method for class 'tiledb_array'
delete_metadata(x, keys, ...)
# S3 method for class 'tiledb_group'
delete_metadata(x, keys, ...)
# S3 method for class 'character'
delete_metadata(x, keys, ctx = NULL, ...)Arguments
- x
An
Robject that points to aTileDBresource whose metadata are to be accessed.- keys
A character vector of metadata key names to be accessed.
- ...
Other arguments passed to methods. Not used.
- ctx
Optional
tiledb::tiledb_ctx()object.
Details
delete_metadata() works similar to metadata<-() with NULL value
but works with a character vector of keys.
The character method requires a valid URI path.
The methods will not alter the mode of the TileDB object; also, the object
will be opened temporarily to access the metadata if it is closed.
See also
set_metadata() and metadata().