Skip to contents

Compared to tiledb_ctx(), this variant does not cache the context and does not accept a character vector of configuration parameters.

Usage

new_context(cfg = NULL)

Arguments

cfg

A configuration object tiledb::tiledb_config().