Open a URI, tiledb::tiledb_array(), tiledb::tiledb_group(), TileDBArray
or TileDBGroup at write mode with an optional timestamp.
Usage
# S3 method for class 'TileDBArray'
open_write(object, timestamp = NULL, ...)
# S3 method for class 'tiledb_array'
open_write(object, timestamp = NULL, ...)
# S3 method for class 'TileDBGroup'
open_write(object, timestamp = NULL, ...)
# S3 method for class 'tiledb_group'
open_write(object, timestamp = NULL, ...)
# S3 method for class 'character'
open_write(object, timestamp = NULL, ctx = NULL, ...)Arguments
- object
An
Robject that contains aTileDBresource pointer.- timestamp
Optional datetime object of class
"POSIXct"to write at this timestamp.- ...
Other arguments passed to methods. Not used.
- ctx
Optional
tiledb::tiledb_ctx()object.
Value
An object of class tiledb_array or tiledb_group depending on
the method; the object is opened in ‘WRITE’ mode.
Details
Opening a character string should be a valid URI path for a TileDB resource.
Objects other than a URI character are implicitly closed if found opened and re-opened at write mode.
Note that when using the timestamp argument, the TileDBArray, TileDBGroup
and their subclasses will have different timestamps from the returning TileDB
object. This is by design, you can not write at timestamp using
TileDBArray and TileDBGroup interface only via open_write() method.