Base class for representing a TileDB Group.
Initialization
A new TileDBGroup instance is initialized using the new() method:
# uri path
uri <- tempdir()
# new instance
obj <- TileDBGroup$new(uri = uri)
# does array exist at this uri
obj$exists() # FALSE
unlink(uri)Super class
TileDBObject -> TileDBGroup
Active bindings
objectAccess the underlying
tiledb::tiledb_group()object.membersAccess the
listof group members.If TileDB group object is closed, it will be opened to get members and close on exit.
Methods
TileDBGroup$open()
Open TileDB group object in read or write mode.
Usage
TileDBGroup$open(mode = c("READ", "WRITE"))TileDBGroup$close()
Close the group object.
All instantiated group members will be closed if opened, and before closing the group object.
TileDBGroup$remove()
Remove member.
Removes an array or group resource from TileDBGroup member list.
TileDBGroup$delete()
Delete member.
Deletes a TileDBGroup's member from disk and removes it from
member list.
TileDBGroup$get_members_df()
List group members.
Usage
TileDBGroup$get_members_df(type = c("ALL", "GROUP", "ARRAY"))TileDBGroup$get_member()
Retrieve a group member by name. If the member isn't already open, it is opened in the same mode as the parent.
TileDBGroup$set_member()
Add new member to the group.
Arguments
objectA
TileDBArrayorTileDBGroupobject to add.nameName to use for the member. By default the base name of the object's URI is used.
relativeAn optional logical value indicating whether the new object's URI is relative to the group's URI. If
NULL(the default), the object's URI is assumed to be relative unless it is atiledb://URI.
TileDBGroup$dump()
Dump the TileDB Group structure to string.